@@ -19,6 +19,7 @@ import com.fasterxml.jackson.core.util.JacksonFeatureSet;
 
 import com.fasterxml.jackson.dataformat.xml.PackageVersion;
 import com.fasterxml.jackson.dataformat.xml.XmlMapper;
+import com.fasterxml.jackson.dataformat.xml.XmlNameProcessor;
 import com.fasterxml.jackson.dataformat.xml.util.CaseInsensitiveNameSet;
 import com.fasterxml.jackson.dataformat.xml.util.StaxUtil;
 
@@ -67,6 +68,21 @@ public class FromXmlParser
          */
         EMPTY_ELEMENT_AS_NULL(false),
 
+        /**
+         * Feature that indicates whether XML Schema Instance attribute
+         * {@code xsi:nil} will be processed automatically -- to indicate {@code null}
+         * values -- or not.
+         * If enabled, {@code xsi:nil} attribute on any XML element will mark such
+         * elements as "null values" and any other attributes or child elements they
+         * might have to be ignored. If disabled this attribute will be exposed like
+         * any other attribute.
+         *<p>
+         * Default setting is {@code true} since processing was enabled in 2.12.
+         *
+         * @since 2.13
+         */
+        PROCESS_XSI_NIL(true),
+
         // 16-Nov-2020, tatu: would have been nice to add in 2.12 but is not
         //    trivial to implement... so leaving out for now
 
@@ -153,7 +169,7 @@ public class FromXmlParser
      */
     protected boolean _closed;
 
-    final protected IOContext _ioContext;
+    protected final IOContext _ioContext;
 
     /*
     /**********************************************************
@@ -179,6 +195,16 @@ public class FromXmlParser
 
     protected String _currText;
 
+    /**
+     * Additional flag that is strictly needed when exposing "mixed" leading
+     * String value as "anonymous" property/string pair. If so, code returns
+     * START_OBJECT first, sets {@code _nextToken} to be {@code FIELD_NAME}
+     * and sets this flag to indicate use of "anonymous" marker.
+     *
+     * @since 2.13
+     */
+    protected boolean _nextIsLeadingMixed;
+
     /*
     /**********************************************************
     /* Parsing state, parsed values
@@ -227,7 +253,7 @@ public class FromXmlParser
      */
 
     public FromXmlParser(IOContext ctxt, int genericParserFeatures, int xmlFeatures,
-            ObjectCodec codec, XMLStreamReader xmlReader)
+             ObjectCodec codec, XMLStreamReader xmlReader, XmlNameProcessor tagProcessor)
         throws IOException
     {
         super(genericParserFeatures);
@@ -235,8 +261,8 @@ public class FromXmlParser
         _ioContext = ctxt;
         _objectCodec = codec;
         _parsingContext = XmlReadContext.createRootContext(-1, -1);
-        _xmlTokens = new XmlTokenStream(xmlReader, ctxt.getSourceReference(),
-                    _formatFeatures);
+        _xmlTokens = new XmlTokenStream(xmlReader, ctxt.contentReference(),
+                    _formatFeatures, tagProcessor);
 
         final int firstToken;
         try {
@@ -253,7 +279,8 @@ public class FromXmlParser
         } else {
             switch (firstToken) {
             case XmlTokenStream.XML_START_ELEMENT:
-            case XmlTokenStream.XML_DELAYED_START_ELEMENT:
+            // Removed from 2.14:
+            // case XmlTokenStream.XML_DELAYED_START_ELEMENT:
                 _nextToken = JsonToken.START_OBJECT;
                 break;
             case XmlTokenStream.XML_ROOT_TEXT:
@@ -668,7 +695,15 @@ public class FromXmlParser
                 _parsingContext = _parsingContext.getParent();
                 break;
             case FIELD_NAME:
-                _parsingContext.setCurrentName(_xmlTokens.getLocalName());
+                // 29-Mar-2021, tatu: [dataformat-xml#442]: special case of leading
+                //    mixed text added
+                if (_nextIsLeadingMixed) {
+                    _nextIsLeadingMixed = false;
+                    _parsingContext.setCurrentName(_cfgNameForTextElement);
+                    _nextToken = JsonToken.VALUE_STRING;
+                } else {
+                    _parsingContext.setCurrentName(_xmlTokens.getLocalName());
+                }
                 break;
             default: // VALUE_STRING, VALUE_NULL
                 // 13-May-2020, tatu: [dataformat-xml#397]: advance `index` anyway; not
@@ -756,7 +791,7 @@ public class FromXmlParser
                 _currText = _xmlTokens.getText();
                 if (_mayBeLeaf) {
                     _mayBeLeaf = false;
-                    // One more refinement (pronunced like "hack") is that if
+                    // One more refinement (pronounced like "hack") is that if
                     // we had an empty String (or all white space), and we are
                     // deserializing an array, we better hide the empty text.
                     // Also: must skip following END_ELEMENT
@@ -792,7 +827,14 @@ XmlTokenStream.XML_END_ELEMENT, XmlTokenStream.XML_START_ELEMENT, token));
                 // but... [dataformat-xml#191]: looks like we can't short-cut, must
                 // loop over again
                 if (_parsingContext.inObject()) {
-                    if ((_currToken != JsonToken.FIELD_NAME) && XmlTokenStream._allWs(_currText)) {
+                    if (_currToken == JsonToken.FIELD_NAME) {
+                        // 29-Mar-2021, tatu: [dataformat-xml#442]: need special handling for
+                        //    leading mixed content; requires 3-token sequence for which _nextToken
+                        //    along is not enough.
+                        _nextIsLeadingMixed = true;
+                        _nextToken = JsonToken.FIELD_NAME;
+                        return (_currToken = JsonToken.START_OBJECT);
+                    } else if (XmlTokenStream._allWs(_currText)) {
                         token = _nextToken();
                         continue;
                     }
@@ -802,6 +844,11 @@ XmlTokenStream.XML_END_ELEMENT, XmlTokenStream.XML_START_ELEMENT, token));
                         token = _nextToken();
                         continue;
                     }
+                    // 29-Mar-2021, tatu: This seems like an error condition...
+                    //   How should we indicate it? As of 2.13, report as unexpected state
+                    throw _constructError(
+"Unexpected non-whitespace text ('"+_currText+"' in Array context: should not occur (or should be handled)"
+);
                 }
 
                 // If not a leaf (or otherwise ignorable), need to transform into property...
@@ -1323,7 +1370,7 @@ XmlTokenStream.XML_END_ELEMENT, XmlTokenStream.XML_START_ELEMENT, token));
             _reportInvalidEOF(String.format(
                     ": expected close marker for %s (start marker at %s)",
                     marker,
-                    _parsingContext.getStartLocation(_ioContext.getSourceReference())),
+                    _parsingContext.startLocation(_ioContext.contentReference())),
                     null);
         }
     }
@@ -1361,6 +1408,10 @@ XmlTokenStream.XML_END_ELEMENT, XmlTokenStream.XML_START_ELEMENT, token));
             return _xmlTokens.next();
         } catch (XMLStreamException e) {
             return StaxUtil.throwAsParseException(e, this);
+        } catch (IllegalStateException e) {
+            // 08-Apr-2021, tatu: Should improve on this, wrt better information
+            //   on issue.
+            throw new JsonParseException(this, e.getMessage(), e);
         }
     }
 
