@@ -10,6 +10,7 @@ import javax.xml.namespace.QName;
 import javax.xml.stream.XMLStreamException;
 import javax.xml.stream.XMLStreamWriter;
 
+import com.fasterxml.jackson.dataformat.xml.XmlNameProcessor;
 import org.codehaus.stax2.XMLStreamWriter2;
 import org.codehaus.stax2.ri.Stax2WriterAdapter;
 
@@ -73,7 +74,25 @@ public class ToXmlGenerator
          *
          * @since 2.10
          */
-        WRITE_NULLS_AS_XSI_NIL(false)
+        WRITE_NULLS_AS_XSI_NIL(false),
+
+        /**
+         * Feature that determines writing of root values of type {@code ObjectNode}
+         * ({@code JsonNode} subtype that represents Object content values),
+         * regarding XML output.
+         * If enabled and {@code ObjectNode} has exactly one entry (key/value pair),
+         * then key of that entry is used as the root element name (and value
+         * is written as contents. Otherwise (if feature disabled, or if root
+         * {@code ObjectNode} has any other number of key/value entries,
+         * root element name is determined using normal logic (either explicitly
+         * configured, or {@code ObjectNode} otherwise).
+         *<p>
+         * Default setting is {@code disabled} in Jackson 2.x, for backwards compatibility:
+         * likely to be changed in 3.0 to {@code enabled}.
+         *
+         * @since 2.13
+         */
+        UNWRAP_ROOT_OBJECT_NODE(false),
         ;
 
         final boolean _defaultState;
@@ -110,17 +129,17 @@ public class ToXmlGenerator
     /**********************************************************
      */
 
-    final protected XMLStreamWriter2 _xmlWriter;
+    protected final XMLStreamWriter2 _xmlWriter;
 
-    final protected XMLStreamWriter _originalXmlWriter;
+    protected final XMLStreamWriter _originalXmlWriter;
     
     /**
      * Marker flag set if the underlying stream writer has to emulate
      * Stax2 API: this is problematic if trying to use {@link #writeRaw} calls.
      */
-    final protected boolean _stax2Emulation;
+    protected final boolean _stax2Emulation;
     
-    final protected IOContext _ioContext;
+    protected final IOContext _ioContext;
 
     /**
      * Bit flag composed of bits that indicate which
@@ -133,7 +152,14 @@ public class ToXmlGenerator
      * We may need to use XML-specific indentation as well
      */
     protected XmlPrettyPrinter _xmlPrettyPrinter;
-    
+
+    /**
+     * Escapes names with invalid XML characters
+     *
+     * @since 2.14
+     */
+    protected XmlNameProcessor _nameProcessor;
+
     /*
     /**********************************************************
     /* XML Output state
@@ -146,7 +172,7 @@ public class ToXmlGenerator
      * @since 2.2
      */
     protected boolean _initialized;
-    
+
     /**
      * Element or attribute name to use for next output call.
      * Assigned by either code that initiates serialization
@@ -173,13 +199,20 @@ public class ToXmlGenerator
      * value should be as CData
      */
     protected boolean _nextIsCData = false;
-    
+
     /**
      * To support proper serialization of arrays it is necessary to keep
      * stack of element names, so that we can "revert" to earlier 
      */
     protected LinkedList<QName> _elementNameStack = new LinkedList<QName>();
-    
+
+    /**
+     * Reusable internal value object
+     *
+     * @since 2.14
+     */
+    protected XmlNameProcessor.XmlName _nameToEncode = new XmlNameProcessor.XmlName();
+
     /*
     /**********************************************************
     /* Life-cycle
@@ -187,7 +220,7 @@ public class ToXmlGenerator
      */
 
     public ToXmlGenerator(IOContext ctxt, int stdFeatures, int xmlFeatures,
-            ObjectCodec codec, XMLStreamWriter sw)
+            ObjectCodec codec, XMLStreamWriter sw, XmlNameProcessor nameProcessor)
     {
         super(stdFeatures, codec);
         _formatFeatures = xmlFeatures;
@@ -195,6 +228,7 @@ public class ToXmlGenerator
         _originalXmlWriter = sw;
         _xmlWriter = Stax2WriterAdapter.wrapIfNecessary(sw);
         _stax2Emulation = (_xmlWriter != sw);
+        _nameProcessor = nameProcessor;
         _xmlPrettyPrinter = (_cfgPrettyPrinter instanceof XmlPrettyPrinter) ?
         		(XmlPrettyPrinter) _cfgPrettyPrinter : null;
     }
@@ -458,9 +492,12 @@ public class ToXmlGenerator
         }
         // Should this ever get called?
         String ns = (_nextName == null) ? "" : _nextName.getNamespaceURI();
-        setNextName(new QName(ns, name));
+        _nameToEncode.namespace = ns;
+        _nameToEncode.localPart = name;
+        _nameProcessor.encodeName(_nameToEncode);
+        setNextName(new QName(_nameToEncode.namespace, _nameToEncode.localPart));
     }
-    
+
     @Override
     public final void writeStringField(String fieldName, String value) throws IOException
     {
@@ -714,6 +751,8 @@ public class ToXmlGenerator
 
             if (_nextIsAttribute) {
                 _xmlWriter.writeAttribute(_nextName.getNamespaceURI(), _nextName.getLocalPart(), text);
+            } else if (checkNextIsUnwrapped()) {
+                _xmlWriter.writeRaw(text);
             } else {
                 _xmlWriter.writeStartElement(_nextName.getNamespaceURI(), _nextName.getLocalPart());
                 _xmlWriter.writeRaw(text);
@@ -738,6 +777,8 @@ public class ToXmlGenerator
 
             if (_nextIsAttribute) {
                 _xmlWriter.writeAttribute(_nextName.getNamespaceURI(), _nextName.getLocalPart(), text.substring(offset, offset + len));
+            } else if (checkNextIsUnwrapped()) {
+                _xmlWriter.writeRaw(text, offset, len);
             } else {
                 _xmlWriter.writeStartElement(_nextName.getNamespaceURI(), _nextName.getLocalPart());
                 _xmlWriter.writeRaw(text, offset, len);
@@ -761,6 +802,8 @@ public class ToXmlGenerator
         try {
             if (_nextIsAttribute) {
                 _xmlWriter.writeAttribute(_nextName.getNamespaceURI(), _nextName.getLocalPart(), new String(text, offset, len));
+            } else if (checkNextIsUnwrapped()) {
+                _xmlWriter.writeRaw(text, offset, len);
             } else {
                 _xmlWriter.writeStartElement(_nextName.getNamespaceURI(), _nextName.getLocalPart());
                 _xmlWriter.writeRaw(text, offset, len);
