@@ -4,14 +4,12 @@ import java.io.UnsupportedEncodingException;
 import java.net.*;
 import java.util.*;
 
-import javax.xml.bind.annotation.*;
-import javax.xml.bind.annotation.adapters.*;
+import jakarta.xml.bind.annotation.*;
+import jakarta.xml.bind.annotation.adapters.*;
 
 import com.fasterxml.jackson.databind.*;
 import com.fasterxml.jackson.databind.introspect.JacksonAnnotationIntrospector;
-import com.fasterxml.jackson.databind.type.TypeFactory;
 import com.fasterxml.jackson.dataformat.xml.*;
-import com.fasterxml.jackson.module.jaxb.JaxbAnnotationIntrospector;
 
 // 30-Jun-2020, tatu: This is deferred and possibly won't be fixed
 //   at all. But leaving failing test here just in case future brings
@@ -110,7 +108,7 @@ public class Issue37AdapterTest extends XmlTestBase
         _nonJaxbMapper = new XmlMapper();
         // Use JAXB-then-Jackson annotation introspector
         AnnotationIntrospector intr =
-            XmlAnnotationIntrospector.Pair.instance(new JaxbAnnotationIntrospector(TypeFactory.defaultInstance()),
+            XmlAnnotationIntrospector.Pair.instance(jakartaXMLBindAnnotationIntrospector(),
                 new JacksonAnnotationIntrospector());
         _jaxbMapper.setAnnotationIntrospector(intr);
     }
