@@ -2,12 +2,11 @@ package com.fasterxml.jackson.dataformat.xml.jaxb;
 
 import java.io.IOException;
 
-import javax.xml.bind.annotation.*;
+import jakarta.xml.bind.annotation.*;
 
-import com.fasterxml.jackson.databind.type.TypeFactory;
 import com.fasterxml.jackson.dataformat.xml.XmlMapper;
 import com.fasterxml.jackson.dataformat.xml.XmlTestBase;
-import com.fasterxml.jackson.module.jaxb.JaxbAnnotationIntrospector;
+import com.fasterxml.jackson.databind.MapperFeature;
 
 public class AttributesWithJAXBTest extends XmlTestBase
 {
@@ -41,16 +40,19 @@ public class AttributesWithJAXBTest extends XmlTestBase
 
     public void testTwoAttributes() throws IOException
     {
-        XmlMapper mapper = new XmlMapper();
-        mapper.setAnnotationIntrospector(new JaxbAnnotationIntrospector(TypeFactory.defaultInstance()));
+        XmlMapper mapper = XmlMapper.builder()
+                .annotationIntrospector(jakartaXMLBindAnnotationIntrospector())
+		.configure(MapperFeature.SORT_PROPERTIES_ALPHABETICALLY, true)
+                .build();
         String xml = mapper.writeValueAsString(new Jurisdiction());
         assertEquals("<Jurisdiction name=\"Foo\" value=\"13\"/>", xml);
     }
 
     public void testAttributeAndElement() throws IOException
     {
-        XmlMapper mapper = new XmlMapper();
-        mapper.setAnnotationIntrospector(new JaxbAnnotationIntrospector(TypeFactory.defaultInstance()));
+        XmlMapper mapper = XmlMapper.builder()
+                .annotationIntrospector(jakartaXMLBindAnnotationIntrospector())
+                .build();
         String xml = mapper.writeValueAsString(new Problem("x", "Stuff"));
         assertEquals("<problem id=\"x\"><description>Stuff</description></problem>", xml);
     }
