@@ -3,9 +3,13 @@ package com.fasterxml.jackson.dataformat.xml.misc;
 import java.util.ArrayList;
 import java.util.List;
 
+import com.fasterxml.jackson.annotation.JsonCreator;
 import com.fasterxml.jackson.annotation.JsonIdentityInfo;
+import com.fasterxml.jackson.annotation.JsonProperty;
+import com.fasterxml.jackson.annotation.JsonSubTypes;
 import com.fasterxml.jackson.annotation.JsonTypeInfo;
 import com.fasterxml.jackson.annotation.ObjectIdGenerators;
+
 import com.fasterxml.jackson.dataformat.xml.XmlMapper;
 import com.fasterxml.jackson.dataformat.xml.XmlTestBase;
 
@@ -47,30 +51,35 @@ public class PolymorphicTypesTest extends XmlTestBase
         public Wrapper(List<TypeWithClassPropertyAndObjectId> data) { this.data = data; }
     }
 
-    /*
-    /**********************************************************
-    /* Set up
-    /**********************************************************
-     */
+    // [dataformat-xml#451]
+    @JsonTypeInfo(use = JsonTypeInfo.Id.DEDUCTION)
+    @JsonSubTypes(@JsonSubTypes.Type(Child451.class))
+    public interface Value451 {}
 
-    protected XmlMapper _xmlMapper;
+    public static class Child451 implements Value451 {
+        private final String property1;
 
-    // let's actually reuse XmlMapper to make things bit faster
-    @Override
-    public void setUp() throws Exception {
-        super.setUp();
-        _xmlMapper = new XmlMapper();
-    }
+        @JsonCreator(mode = JsonCreator.Mode.PROPERTIES)
+        public Child451(@JsonProperty("property1") String property1) {
+            this.property1 = property1;
+        }
+
+        public String getProperty1() {
+            return property1;
+        }
+    }    
 
     /*
-    /**********************************************************
-    /* Unit tests
-    /**********************************************************
+    /**********************************************************************
+    /* Test methods
+    /**********************************************************************
      */
 
+    private final XmlMapper MAPPER = newMapper();
+
     public void testAsClassProperty() throws Exception
     {
-        String xml = _xmlMapper.writeValueAsString(new SubTypeWithClassProperty("Foobar"));
+        String xml = MAPPER.writeValueAsString(new SubTypeWithClassProperty("Foobar"));
 
         // Type info should be written as an attribute, so:
         final String exp = 
@@ -80,7 +89,7 @@ public class PolymorphicTypesTest extends XmlTestBase
                 ;
         assertEquals(exp, xml);
         
-        Object result = _xmlMapper.readValue(xml, BaseTypeWithClassProperty.class);
+        Object result = MAPPER.readValue(xml, BaseTypeWithClassProperty.class);
         assertNotNull(result);
         assertEquals(SubTypeWithClassProperty.class, result.getClass());
         assertEquals("Foobar", ((SubTypeWithClassProperty) result).name);
@@ -88,16 +97,14 @@ public class PolymorphicTypesTest extends XmlTestBase
         
     public void testAsClassObject() throws Exception
     {
-        String xml = _xmlMapper.writeValueAsString(new SubTypeWithClassObject("Foobar"));
-        Object result = _xmlMapper.readValue(xml, BaseTypeWithClassObject.class);
+        String xml = MAPPER.writeValueAsString(new SubTypeWithClassObject("Foobar"));
+        Object result = MAPPER.readValue(xml, BaseTypeWithClassObject.class);
         assertNotNull(result);
         assertEquals(SubTypeWithClassObject.class, result.getClass());
         assertEquals("Foobar", ((SubTypeWithClassObject) result).name);
     }
 
-    /**
-     * Test for [dataformat-xml#81]
-     */
+    // Test for [dataformat-xml#81]
     public void testAsPropertyWithObjectId() throws Exception
     {
         List<TypeWithClassPropertyAndObjectId> data = new ArrayList<PolymorphicTypesTest.TypeWithClassPropertyAndObjectId>();
@@ -105,11 +112,23 @@ public class PolymorphicTypesTest extends XmlTestBase
         data.add(object);
         // This will be written as an id reference instead of object; as such, no type info will be written.
         data.add(object);
-        String xml = _xmlMapper.writeValueAsString(new Wrapper(data));
-        Wrapper result = _xmlMapper.readValue(xml, Wrapper.class);
+        String xml = MAPPER.writeValueAsString(new Wrapper(data));
+        Wrapper result = MAPPER.readValue(xml, Wrapper.class);
         assertNotNull(result);
         assertSame(result.data.get(0), result.data.get(1));
         assertEquals("Foobar", result.data.get(0).id);
     }
+
+    // Test for [dataformat-xml#451]
+    public void testDeduction() throws Exception
+    {
+        String xml = MAPPER.writeValueAsString(new Child451("value1"));
+        assertTrue(xml.contains("<property1>value1</property1>"));
+
+        // and try reading back for funsies
+        Value451 result = MAPPER.readValue(xml, Value451.class);
+        assertNotNull(result);
+        assertEquals(Child451.class, result.getClass());
+    }
 }
    
\ No newline at end of file
